<?xml version="1.0" ?><!DOCTYPE TS><TS language="am_ET" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>ዲፕኢን ምስል መመልከቻ</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>እትም:</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>ምስል</translation>
    </message>
    <message>
        <source>images</source>
        <translation>ምስል</translation>
    </message>
    <message>
        <source>album</source>
        <translation>አልበም</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>አልበሞች</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>የ ማዋሀጃ አስተዳዳሪ </translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>ማዋሀጃ</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>መሰረዣ</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>እሺ</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>አዲስ አልበም</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>ያልተሰየመ</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>በ ቅርብ ጊዜ የ መጡ</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>እኔ የምወዳቸው</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>እርስዎ በ እርግጥ ይህን አልበም ማጥፋት ይፈልጋሉ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>መሰረዣ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>ማጥፊያ</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>ወደ ኋላ</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>እኔ የምወዳቸው</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>የ ሰአት መስመር</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>መጨመሪያ</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>እርስዎ መጨመር ይችላሉ ዳይሬክቶሪ ማዋሀጃ ወይንም ይጎትቱ እና ይጣሉ ምስል ወደ ሰአት መስመር ውስጥ</translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>ያልተሰየመ</translation>
    </message>
    <message>
        <source>View</source>
        <translation>መመልከቻ</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>ተንሸራታች ማሳያ</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>እንደገና መሰየሚያ</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>ኮፒ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>ማጥፊያ</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>ዲፕኢን ምስል መመልከቻ</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>ምስሎች</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>መሰረዣ</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>እሺ</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>እርስዎ በ እርግጥ ይህን አልበም ማጥፋት ይፈልጋሉ?</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>ማዋሀጃ እና መፍጠሪያ</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>ማዋሀጃ</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>እርስዎ በ እርግጥ መጨመር ይፈልጋሉ ወደ ማዋሀጃ ዝርዝር ውስጥ እና መፍጠር የ አልበም ስም በዚህ ፎልደር ውስጥ የ ተሰየመውን?</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>ተሳክቶ ተልኳል</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>መላክ አልተቻለም</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>ማስቀመጫ</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>እርስዎ በ እርግጥ ይህን ስእል ወደ ቆሻሻ መጣል ይፈልጋሉ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>መሰረዣ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>ማጥፊያ</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>የ ምስል መረጃ</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>መመልከቻ</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>በ ሙሉ መመልከቻ ዘዴ</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>ተንሸራታች ማሳያ</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>ማተሚያ</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>ኮፒ</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>ወደ ቁራጭ ሰሌዳ ኮፒ ማድረጊያ</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>ከ አልበም ውስጥ ማስወገጃ</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>የምወዳቸው</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>የማልወዳቸው</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>ማዞሪያ ከ ግራ ወደ ቀኝ</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>ማዞሪያ ከ ቀኝ ወደ ግራ</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>እንደ ግድግዳ ወረቀት ማሰናጃ</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>በ ፋይል አስተዳዳሪ ውስጥ ማሳያ</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>የ ምስል መረጃ</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>መጨመሪያ</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>እርስዎ መጨመር ይችላሉ ዳይሬክቶሪ ማዋሀጃ ወይንም ይጎትቱ እና ይጣሉ ምስል ወደ ሰአት መስመር ውስጥ</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>ወደ አልበም መጨመሪያ</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>ወደ አዲስ አልበም መጨመሪያ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>ዳይሬክቶሪ መክፈቻ</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>እርስዎ ይህን ምስል ለ ማየት በቂ ፍቃድ የለዎትም</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>ስም</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>አይነት</translation>
    </message>
    <message>
        <source>Date photoed</source>
        <translation>ፎቶ የ ተነሳበት ቀን</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>የ ተሻሻለበት ቀን</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File size</source>
        <translation>የ ፋይል መጠን</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>የ ቀለም ቦታ</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>የ ተጋለጠበት ዘዴ </translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>የ ተጋለጠበት ፕሮግራም </translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>የ ተጋለጠበት ጊዜ</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>ፍላሽ</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>ብርሃን መቆጣጠሪያ</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>የ ትኩረት እርዝመት </translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>ከፍተኛ ብርሃን መቆጣጠሪያ</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>የ ብርሃን ፍጥነት</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>ነጭ ማካካሻ</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>ፍላሽ ማካካሻ</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>የ ካሜራው አይነት</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>የ ሌንስ አይነት</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scale to:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Millimeters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Centimeters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Inches</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image Position</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>መሸፈኛ</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>መቀየሪያ</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>ተንሸራታች</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>ቀለበት</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>ዳይሬክቶሪ ይምረጡ</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>የዚህ ዳይሬክቶሪ ማዋሀጃ ተሰናክሏል</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>ፎልደር መጨመሪያ</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>የ ዳይሬክቶሪ ማዋሀጃ አስተዳዳሪ</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>የ ዳይሬክቶሪ ዝርዝር ባዶ ነው</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>ማዋሀጃ መሰረዣ </translation>
    </message>
    <message>
        <source>Images</source>
        <translation>ምስሎች</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>አካሉ ተወግዷል</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>ዳይሬክቶሪው አልተገኘም</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>በ ማስላት ላይ...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>ምስል በ መመልከት ላይ</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>አልበም</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>ማሰናጃ</translation>
    </message>
    <message>
        <source>View</source>
        <translation>መመልከቻ</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>በ ሙሉ መመልከቻ ዘዴ</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>ተንሸራታች ማሳያ</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>ማሳያ መጨረሻ</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>ኮፒ</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>ከ አልበም ውስጥ ማስወገጃ</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>የምወዳቸው</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>የማልወዳቸው</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>ማዞሪያ ከ ግራ ወደ ቀኝ</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>ማዞሪያ ከ ቀኝ ወደ ግራ</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>እንደ ግድግዳ ወረቀት ማሰናጃ</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>በ ፋይል አስተዳዳሪ ውስጥ ማሳያ</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>የ ምስል መረጃ</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>ያለፈው</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>ይቀጥሉ</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>ያለፈው መመልከቻ</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>የሚቀጥለው መመልከቻ</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>አዲስ አልበም</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>እንደገና መሰየሚያ</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>እርዳታ</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>መውጫ</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>አቋራጭ ማሳያ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>እባክዎን አዲስ አቋራጭ ያስገቡ </translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>አቋራጭ</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>ስእል መመልከቻ</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>አልበም</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>ነባር እንደ ነበር መመለሻ</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>መመልከቻ</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>በ ሙሉ መመልከቻ ዘዴ</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>ተንሸራታች ማሳያ</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>ማሳያ መጨረሻ</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>ማተሚያ</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>ኮፒ</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>ከ አልበም ውስጥ ማስወገጃ</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>የምወዳቸው</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>የማልወዳቸው</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>ማዞሪያ ከ ግራ ወደ ቀኝ</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>ማዞሪያ ከ ቀኝ ወደ ግራ</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>እንደ ግድግዳ ወረቀት ማሰናጃ</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>በ ፋይል አስተዳዳሪ ውስጥ ማሳያ</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>የ ምስል መረጃ</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>አዲስ አልበም</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>እንደገና መሰየሚያ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>ማጥፊያ</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation>ማሳያ መጨረሻ</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>ማጫወቻ / ማስቆሚያ</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>ተንሸራታች ማሰናጃ</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>ውጤት መቀየሪያ</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>የሚፈጀው ጊዜ</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>መቀየሪያ የሚፈጀውን ጊዜ </translation>
    </message>
    <message>
        <source>second</source>
        <translation>ሰከንድ</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>ወደ ኋላ</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>የ ምስል አስተዳዳሪ</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>እኔ የምወዳቸው</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fit to window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>ምንም የ ምስል ፋይል አልተገኘም</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation>%1 ምስል</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation>%1 ምስሎች</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>የ ማዋሀጃ አስተዳዳሪ </translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>በ ማዋሀድ ላይ</translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>አልበም</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>መጨመሪያ</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>እርስዎ መጨመር ይችላሉ ዳይሬክቶሪ ማዋሀጃ ወይንም ይጎትቱ እና ይጣሉ ምስል ወደ ሰአት መስመር ውስጥ</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>ወደ አልበም መጨመሪያ</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>ወደ አዲስ አልበም ውስጥ መጨመሪያ</translation>
    </message>
    <message>
        <source>View</source>
        <translation>መመልከቻ</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>በ ሙሉ መመልከቻ ዘዴ</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>ተንሸራታች ማሳያ</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>ማተሚያ</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>ኮፒ</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>ወደ ቁራጭ ሰሌዳ ኮፒ ማድረጊያ</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>የምወዳቸው</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>የማልወዳቸው</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>ማዞሪያ ከ ግራ ወደ ቀኝ</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>ማዞሪያ ከ ቀኝ ወደ ግራ</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>እንደ ግድግዳ ወረቀት ማሰናጃ</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>በ ፋይል አስተዳዳሪ ውስጥ ማሳያ</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>የ ምስል መረጃ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>ተንሸራታች ማሰናጃ</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>ውጤት</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>የሚፈጀው ጊዜ</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>አቋራጭ</translation>
    </message>
    <message>
        <source>View</source>
        <translation>መመልከቻ</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>አልበም</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>dd MMMM yyyy</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>እኔ የምወዳቸው</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>በ ቅርብ ጊዜ የ መጡ</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>አዲስ አልበም</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>ማሰናጃ</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>ዲፕኢን የ ምስል መመልከቻ ዘመናዊ &amp; ቀላል የ ምስል አስተዳዳሪ ነው</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>የ ምስል አስተዳዳሪ: ምስል መመልከቻ: እና መሰረታዊ የ ምስል ማረሚያ</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>ጥቁር ገጽታ</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>የ ሰአት መስመር</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>ወደ አልበም መጨመሪያ</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>ወደ አዲስ አልበም መጨመሪያ</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>ከ ሙሉ መመልከቻ ዘዴ መውጫ</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>በ ሙሉ መመልከቻ ዘዴ</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>ተንሸራታች ማሳያ</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>ማተሚያ</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>ኮፒ</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>ወደ ቁራጭ ሰሌዳ ኮፒ ማድረጊያ</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>ከ አልበም ውስጥ ማስወገጃ</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>የምወዳቸው</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>የማልወዳቸው</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>የ መቃኛ መስኮት ማሳያ</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>የ መቃኛ መስኮት መደበቂያ</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>ማዞሪያ ከ ግራ ወደ ቀኝ</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>ማዞሪያ ከ ቀኝ ወደ ግራ</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>እንደ ግድግዳ ወረቀት ማሰናጃ</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>በ ፋይል አስተዳዳሪ ውስጥ ማሳያ</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>የ ምስል መረጃ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All images</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>